import csv
import os

def asana_to_todoist(input_file, output_file):
    """
    Convert Asana CSV to Todoist CSV format.
    """

    with open(input_file, 'r', newline='', encoding='utf-8-sig') as infile:
        reader = csv.DictReader(infile)

        # Create a new CSV for Todoist
        with open(output_file, 'w', newline='', encoding='utf-8') as outfile:
            fieldnames = ['TYPE', 'CONTENT', 'DESCRIPTION', 'PRIORITY', 'INDENT', 'AUTHOR', 'RESPONSIBLE', 'DATE', 'DATE_LANG', 'TIMEZONE']
            writer = csv.DictWriter(outfile, fieldnames=fieldnames)
            writer.writeheader()

            for row in reader:
                task_type = 'completed task' if row['Completed At'] else 'task'
                writer.writerow({
                    'TYPE': task_type,
                    'CONTENT': row['Name'],
                    'DESCRIPTION': row['Notes'],
                    'PRIORITY': '4',
                    'INDENT': '1',
                    'AUTHOR': '',
                    'RESPONSIBLE': '',
                    'DATE': '',
                    'DATE_LANG': '',
                    'TIMEZONE': ''
                })

if __name__ == '__main__':
    # List all CSV files in the current directory
    csv_files = [f for f in os.listdir() if f.endswith('.csv')]
    
    if len(csv_files) == 1:
        input_file = csv_files[0]
        output_file = 'todoist_import.csv'
        asana_to_todoist(input_file, output_file)
    else:
        print(f"Expected 1 CSV file in directory, but found {len(csv_files)}. Please ensure there's only one CSV file.")
